# COPR Ligenix's spec file for glpi-plugin-metademands
#
# Copyright (c) 2022-2024 Jean-Marc Liger 
#
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname metademands
%global glpi_min   10.0.0
%global glpi_max   10.1.0


Name:           glpi-plugin-%{pluginname}
Version:        3.3.18
Release:        1%{?dist}
Summary:        GLPI Plugin to add complex request handling
Summary(fr):    Extension GLPI de gestion de requêtes complexes

License:        AGPLv3+
URL:            https://github.com/InfotelGLPI/%{pluginname}
  
Source0:        https://github.com/InfotelGLPI/%{pluginname}/releases/download/v%{version}/glpi-%{pluginname}-%{version}.tar.bz2

BuildArch:      noarch
BuildRequires:  gettext

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif

Provides:       bundled(php-fpdf)


%description
This plugin allows you to create wizards to handle complex requests in GLPI
that will generate child tickets assigned to different groups of technicians.


%description -l fr
Cette extension permet de créer des wizards pour gérer des demandes complexes dans GLPI
qui génèreront des tickets enfants attribués à des groupes de techniciens différents.


%prep
%setup -q -c 

# display compatibility check
grep 'min' %{pluginname}/setup.php

# remove unused files
rm %{pluginname}/.gitignore
rm %{pluginname}/composer.*
rm %{pluginname}/vendor/fpdf/fpdf/composer.json

# move doc files
mkdir docs
mv %{pluginname}/README.md                  docs/
mv %{pluginname}/'ManageRedirect Error.txt' docs/

# protect install files
cat >httpd <<EOF
<Directory /usr/share/glpi/plugins/%{pluginname}/install>
    <IfModule mod_authz_core.c>
        Require all denied
    </IfModule>
    <IfModule !mod_authz_core.c>
        Order Allow,Deny
        Deny from all
    </IfModule>
</Directory>
EOF

# create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# regenerate the locales
for po in %{pluginname}/locales/*.po
do
   msgfmt $po -o $(dirname $po)/$(basename $po .po).mo
done


%install
mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

# ===== apache =====
mkdir -p %{buildroot}/%{_sysconfdir}/httpd/conf.d/
install --mode 644 httpd %{buildroot}/%{_sysconfdir}/httpd/conf.d/%{name}.conf

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc docs/*
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/ajax
%{_datadir}/glpi/plugins/%{pluginname}/css
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/img
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/install
%{_datadir}/glpi/plugins/%{pluginname}/lib
%{_datadir}/glpi/plugins/%{pluginname}/pics
%{_datadir}/glpi/plugins/%{pluginname}/scripts
%{_datadir}/glpi/plugins/%{pluginname}/templates
%{_datadir}/glpi/plugins/%{pluginname}/vendor


%changelog
* Tue Dec 31 2024 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.18-1
- Version 3.3.18

* Mon Oct 14 2024 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.16-1
- Version 3.3.16

* Mon Sep 16 2024 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.15-1
- Version 3.3.15

* Mon Mar 18 2024 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.10-1
- Version 3.3.10

* Fri Nov 24 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.7-1
- Version 3.3.7

* Sat Oct 21 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.6-1
- Version 3.3.6

* Wed Sep 27 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.4-1
- Version 3.3.4

* Wed Aug 30 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.3-1
- Version 3.3.3

* Fri Jul 28 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.2-1
- Version 3.3.2

* Thu Jul 13 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.1-1
- Version 3.3.1

* Fri Jul 07 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.0-1
- Version 3.3.0

* Mon May 01 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.2.19-1
- Version 3.2.19

* Wed Nov 30 2022 Jean-Marc Liger <ligenix@iscp.fr> - 3.2.13-1
- Version 3.2.13

* Mon Nov 28 2022 Jean-Marc Liger <ligenix@iscp.fr> - 3.2.12-1
- Version 3.2.12

* Thu Nov 24 2022 Jean-Marc Liger <ligenix@iscp.fr> - 3.2.8-1
- Version 3.2.8
- Add docs

* Wed Oct 26 2022 Jean-Marc Liger <ligenix@iscp.fr> - 3.2.7-1
- Version 3.2.7 for GLPI 10.0.x

* Wed Oct 26 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.7.9-1
- Version 2.7.9 for GLPI 9.5.x
- Initial RPM based on Remi Collet previous GLPI plugins spec files
